@@ -158,19 +158,17 @@ sub stc_find_libperl {
 	my $link        = ( $libperlname =~ /\.a$/ ) ? 'static' : 'shared';
 
 	if ( $link eq 'static' ) {
-		return qq($archlib/CORE/$libperlname);
+		return '';
 	} else {
-		my $returnpath     = '';
-		my $testforlibperl = $libperlname;
-		$testforlibperl =~ s/\.a$/\.dylib/;
-		my $dllpath = qq($archlib/CORE/$testforlibperl);
+		my $returnpath = '';
+		my $dllpath    = qq($archlib/CORE/$libperlname);
 		return $dllpath if -f $dllpath;
 
 		# search elsewhere
 
 		my @libperlpaths = split( /\s+/, $Config::Config{libpth} );
 		for my $libdir (@libperlpaths) {
-			if ( -f qq($libdir/$testforlibperl) ) {
+			if ( -f qq($libdir/$libperlname) ) {
 				$returnpath = (qq($libdir/$libperlname));
 				last;
 			}
